/**
 * class Avatar
 *
 * Contains logic and rendering routines for the player avatar.
 *
 * @author Clint Bellanger
 * @license GPL
 */

#include "Avatar.h"

Avatar::Avatar(SDL_Surface *_screen, InputState *_inp, Map_Iso *_map) {
	screen = _screen;
	inp = _inp;
	map = _map;
	
	// other init
	curState = AVATAR_STANCE;
	pos.x = map->spawn.x;
	pos.y = map->spawn.y;
	direction = map->spawn_dir;
		
	curFrame = 1;
	dispFrame = 0;
	animFwd = true;
	lockSwing = false;
	lockCast = false;
	lockShoot = false;
	
	speed = 6;
	dspeed = 4;
	
	loadGraphics();
}

void Avatar::loadGraphics() {
	
	sprites = IMG_Load("images/male_sprites.png");
	if(!sprites) {
		fprintf(stderr, "Couldn't load image: %s\n", IMG_GetError());
	}
}

bool Avatar::pressing_move() {
	if(inp->pressing[UP] ||
	   inp->pressing[DOWN] ||
	   inp->pressing[LEFT] ||
	   inp->pressing[RIGHT])
		return true;
	return false;
}

bool Avatar::move() {
	switch (direction) {
		case 0:
			return map->collider.move(pos.x, pos.y, -1, 1, dspeed);
		case 1:
			return map->collider.move(pos.x, pos.y, -1, 0, speed);
		case 2:
			return map->collider.move(pos.x, pos.y, -1, -1, dspeed);
		case 3:
			return map->collider.move(pos.x, pos.y, 0, -1, speed);
		case 4:
			return map->collider.move(pos.x, pos.y, 1, -1, dspeed);
		case 5:
			return map->collider.move(pos.x, pos.y, 1, 0, speed);
		case 6:
			return map->collider.move(pos.x, pos.y, 1, 1, dspeed);
		case 7:
			return map->collider.move(pos.x, pos.y, 0, 1, speed);
	}
	return true;
}

void Avatar::set_direction() {
	// handle direction changes
	if(inp->pressing[UP] && inp->pressing[LEFT]) direction = 1;
	else if(inp->pressing[UP] && inp->pressing[RIGHT]) direction = 3;
	else if(inp->pressing[DOWN] && inp->pressing[RIGHT]) direction = 5;
	else if(inp->pressing[DOWN] && inp->pressing[LEFT]) direction = 7;
	else if(inp->pressing[LEFT]) direction = 0;
	else if(inp->pressing[UP]) direction = 2;
	else if(inp->pressing[RIGHT]) direction = 4;
	else if(inp->pressing[DOWN]) direction = 6;
}

void Avatar::logic() {

	switch(curState) {
		case AVATAR_STANCE:
			if (animFwd) {
				curFrame++;
				if (curFrame >= 24) {
					curFrame = 23;
					animFwd = false;
				}
			}
			else {
				curFrame--;
				if (curFrame <= -1) {
					curFrame = 0;
					animFwd = true;
				}
				
			}
			dispFrame = curFrame / 6;
			
			// handle transitions to RUN
			set_direction();
			if (pressing_move()) {
				if (move()) {
					curFrame = 1;
					curState = AVATAR_RUN;
				}
			}

			break;
			
		case AVATAR_RUN:
			curFrame++;
			if (curFrame >= 16) curFrame = 0;
			dispFrame = (curFrame / 2) + 4;
			
			// handle direction changes
			set_direction();
			
			// handle transition to STANCE
			if (!pressing_move()) {
				curState = AVATAR_STANCE;
			} 
			else if (!move()) {
				curState = AVATAR_STANCE;
			}	
							
			break;
			
		default:
			break;
	}
	
	// calc new cam position from player position
	
	// cam is focused at player position
	map->cam.x = pos.x;
	map->cam.y = pos.y;
	map->hero_tile.x = pos.x / 32;
	map->hero_tile.y = pos.y / 32;
}

Renderable Avatar::getRender() {
	Renderable r;
	r.map_pos.x = pos.x;
	r.map_pos.y = pos.y;
	r.sprite = sprites;
	r.src = new SDL_Rect();
	r.src->x = 128 * dispFrame;
	r.src->y = 128 * direction;
	r.src->w = 128;
	r.src->h = 128;
	r.offset.x = 64;
	r.offset.y = 112;
	return r;	
}
