/**
 * class Avatar
 *
 * Contains logic and rendering routines for the player avatar.
 *
 * @author Clint Bellanger
 * @license GPL
 */
#ifndef AVATAR_H
#define AVATAR_H

#include "SDL.h"
#include "SDL_image.h"
#include "Utils.h"
#include "InputState.h"
#include "map_iso.h"

// AVATAR State enum
const int AVATAR_STANCE = 0;
const int AVATAR_RUN = 1;
const int AVATAR_SWING = 2;
const int AVATAR_BLOCK = 3;
const int AVATAR_HIT = 4;
const int AVATAR_DIE = 5;
const int AVATAR_CAST = 6;
const int AVATAR_SHOOT = 7;

class Avatar {
private:
	void loadGraphics();
	SDL_Surface *screen;
	SDL_Surface *sprites;
	InputState *inp;
	Map_Iso *map;
	
	int curState;
	Point pos;
	int direction;
	bool lockSwing;
	bool lockCast;
	bool lockShoot;
	int curFrame;
	int dispFrame;
	bool animFwd;
	int speed;
	int dspeed;
	
public:
	Avatar(SDL_Surface *_screen, InputState *_inp, Map_Iso *_map);
	void logic();
	void render();
	bool pressing_move();	
	bool move();
	void set_direction();
	Renderable getRender();
};

#endif
