/**
 * class GameEngine
 *
 * Hands off the logic and rendering for the current game mode
 *
 * @author Clint Bellanger
 * @license GPL
 */

#include "SDL.h"
#include "SDL_image.h"
#include "GameEngine.h"

GameEngine::GameEngine(SDL_Surface *_screen, InputState *_inp) {
	screen = _screen;
	inp = _inp;
	done = false;
	
	map = new Map_Iso(screen);
	pc = new Avatar(screen, inp, map);
	
}

/**
 * Process all actions for a single frame
 */
void GameEngine::logic() {
	
	pc->logic();
	if (inp->pressing[CANCEL] || inp->done) done = true;
	
}

/**
 * Render all graphics for a single frame
 */
void GameEngine::render() {

	// The strategy here is to make a list of Renderables from all objects not already on the map.
	// Pass this list/array to the map, which will draw them inline with the map tiles/objects.
	
	Renderable r;
	r = pc->getRender();
	map->render(r);
}
