/**
 * class InputState
 *
 * Handles keyboard and mouse states
 *
 * @author Clint Bellanger
 * @license GPL
 */

#include "InputState.h"
#include "SDL.h"

InputState::InputState(void) {
	binding[CANCEL] = SDLK_ESCAPE;
	binding[ACCEPT] = SDLK_RETURN;
	binding[UP] = SDLK_UP;
	binding[DOWN] = SDLK_DOWN;
	binding[LEFT] = SDLK_LEFT;
	binding[RIGHT] = SDLK_RIGHT;
	for (int key=0; key<key_count; key++) {
		pressing[key] = false;	
	}
	done = false;
}
	
void InputState::handle() {
	SDL_Event event;
	
	/* Check for events */
	while (SDL_PollEvent (&event)) {
		switch (event.type) {
				
			case SDL_MOUSEMOTION:
				break;
			case SDL_MOUSEBUTTONDOWN:
				break;
			case SDL_KEYDOWN:
				for (int key=0; key<key_count; key++) {
					if (event.key.keysym.sym == binding[key]) {
						pressing[key] = true;
					}
				}
				break;
			case SDL_KEYUP:
				for (int key=0; key<key_count; key++) {
					if (event.key.keysym.sym == binding[key]) {
						pressing[key] = false;
					}
				}
				break;
			case SDL_QUIT:
				done = 1;
				break;
			default:
				break;
		}
	}
		
}
