/**
 * Generic main.cpp for game engines
 *
 */
   
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <math.h>

#include "SDL.h"
#include "SDL_image.h"

#include "InputState.h"
#include "GameEngine.h"

SDL_Surface *screen;
InputState *inp;
GameEngine *eng;

static void init() {
	/* SDL Inits */
	// Init SDL video subsystem
	if ( SDL_Init (SDL_INIT_VIDEO) < 0 ) {
		
        fprintf(stderr, "Couldn't initialize SDL: %s\n", SDL_GetError());
		exit(1);
	}

	Uint32 flags = 0;
    
	flags = SDL_HWSURFACE | SDL_DOUBLEBUF | SDL_FULLSCREEN;
    
	// Create window
	screen = SDL_SetVideoMode (640, 480, 0, flags);
	if (screen == NULL) {
		
        fprintf (stderr, "Couldn't set 640x480 OpenGL video mode: %s\n", SDL_GetError());
		SDL_Quit();
		exit(2);
	}
	
	/* Shared game units setup */
	inp = new InputState();
	eng = new GameEngine(screen, inp);
}

static void mainLoop () {

	bool done = false;
	int fps = 24;
	int delay = 1000/fps;
	int prevTicks = SDL_GetTicks();
	int nowTicks;
	
	while ( !done ) {
		
		// black out
		SDL_FillRect(screen, NULL, 0);

		inp->handle();
		eng->logic();
		eng->render();
		
		// Engine done means the user escapes the main game menu.
		// Input done means the user closes the window.
		done = eng->done || inp->done;
		
		nowTicks = SDL_GetTicks();
		if (nowTicks - prevTicks < delay) SDL_Delay(delay - (nowTicks - prevTicks));
		prevTicks = nowTicks;
		
		SDL_Flip(screen);
		
		done = eng->done;
	}
}

int main(int argc, char *argv[])
{

	init();
	mainLoop ();
	SDL_Quit();
	
	return 0;
}
